@@ -2,7 +2,6 @@ import argparse
 import sys
 
 import numpy as np
-from maestrowf.datastructures.core import ParameterGenerator
 
 
 def process_args(args):
@@ -19,23 +18,6 @@ def process_args(args):
     np.save(args.outfile, x)
 
 
-def get_custom_generator():
-    """
-    Create a custom populated ParameterGenerator.
-
-    :returns: A ParameterGenerator populated with parameters.
-    """
-    p_gen = ParameterGenerator()
-    params = {
-        "X0": {"values": [x0 for x0, x1, x2 in x], "label": "X0.%%"},
-        "X1": {"values": [x1 for x0, x1, x2 in x], "label": "X1.%%"},
-        "X2": {"values": [x2 for x0, x1, x2 in x], "label": "X2.%%"},
-    }
-    for key, value in params.items():
-        p_gen.add_parameter(key, value["values"], value["label"])
-    return p_gen
-
-
 def setup_argparse():
     parser = argparse.ArgumentParser("Generate some samples!")
     parser.add_argument("-n", help="number of samples", default=100, type=int)
